@@ -197,7 +197,7 @@ int hydra_get_options(char *options[]) {
 	widget = lookup_widget(GTK_WIDGET(wndMain), "entProtocol");
 	tmp = (char *) gtk_entry_get_text((GtkEntry *) widget);
 	
-	if ( !strcmp(tmp, "http") || !strcmp(tmp, "https")) {
+	if ( !strncmp(tmp, "http-", 5) || !strncmp(tmp, "https-", 6)) {
 		options[i++] = "-m";
 		widget = lookup_widget(GTK_WIDGET(wndMain), "entHTTPURL");
 		options[i++] = (char *) gtk_entry_get_text((GtkEntry *) widget);
@@ -253,7 +253,7 @@ int hydra_get_options(char *options[]) {
 		options[i++] = "-m";
 		options[i++] = (char *) gtk_entry_get_text((GtkEntry *) widget);
 
-	} else if (!strcmp(tmp, "cvs")) {
+	} else if (!strcmp(tmp, "cvs")||!strcmp(tmp, "svn")) {
 		widget = lookup_widget(GTK_WIDGET(wndMain), "entCVS");
 		options[i++] = "-m";
 		options[i++] = (char *) gtk_entry_get_text((GtkEntry *) widget);
@@ -298,7 +298,7 @@ int hydra_get_options(char *options[]) {
 		widget = lookup_widget(GTK_WIDGET(wndMain), "radioProxy2");
 
 		/* which variable do we set? */
-		if ((!strcmp(tmp, "http")) && ( gtk_toggle_button_get_active((GtkToggleButton *) widget))) {
+		if ((!strncmp(tmp, "http-", 5)) && ( gtk_toggle_button_get_active((GtkToggleButton *) widget))) {
 			setenv("HYDRA_PROXY_HTTP", gtk_entry_get_text((GtkEntry *) widget2), 1);
 		} else {
 			setenv("HYDRA_PROXY_CONNECT", (char *) gtk_entry_get_text((GtkEntry *) widget2), 1);
